@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Convert notes and chords to Roman numeral notation
 
-our $VERSION = '0.1400';
+our $VERSION = '0.1401';
 
 use List::MoreUtils qw/ any first_index /;
 use Moo;
@@ -287,7 +287,7 @@ Music::ToRoman - Convert notes and chords to Roman numeral notation
 
 =head1 VERSION
 
-version 0.1400
+version 0.1401
 
 =head1 SYNOPSIS
 
@@ -299,20 +299,21 @@ version 0.1400
   );
 
   my $roman = $mtr->parse('Am');  # i (minor)
-  $roman = $mtr->parse('Bo');     # iio (diminished)
   $roman = $mtr->parse('Bdim');   # iio (diminished)
-  $roman = $mtr->parse('Bø');     # iio (diminished)
+  $roman = $mtr->parse('B dim');  # ii o "
+  $roman = $mtr->parse('Bo');     # iio "
+  $roman = $mtr->parse('Bø');     # iio "
   $roman = $mtr->parse('Bb');     # bII (flat-two major)
   $roman = $mtr->parse('CM');     # III (major)
-  $roman = $mtr->parse('C');      # III (major)
+  $roman = $mtr->parse('C');      # III "
   $roman = $mtr->parse('Cm9/G');  # iii9/VII (minor ninth with seven bass)
   $roman = $mtr->parse('Cm9/Bb'); # iii9/bii (minor ninth with flat-two bass)
   $roman = $mtr->parse('D sus4'); # IV sus4 (major suspended)
-  $roman = $mtr->parse('DMaj7');  # IV maj7 (major seventh)
-  $roman = $mtr->parse('D△7');    # IV maj7 (major seventh)
+  $roman = $mtr->parse('DMaj7');  # IVmaj7 (major seventh)
+  $roman = $mtr->parse('D△7');    # IV maj7 "
   $roman = $mtr->parse('E7');     # V7 (dominant seventh)
   $roman = $mtr->parse('Em7');    # v7 (minor seventh)
-  $roman = $mtr->parse('Fmin7');  # vi min7 (minor seventh)
+  $roman = $mtr->parse('Fmin7');  # vimin7 "
   $roman = $mtr->parse('G+');     # VII+ (augmented)
 
   $mtr = Music::ToRoman->new(
@@ -328,9 +329,9 @@ version 0.1400
   $roman = $mtr->parse('E');      # v
   $roman = $mtr->parse('F#');     # vi
   $roman = $mtr->parse('G');      # VII
-  $roman = $mtr->parse('Amin7');  # i min7
+  $roman = $mtr->parse('Amin7');  # imin7
   $roman = $mtr->parse('Bo');     # iio
-  $roman = $mtr->parse('CMaj7');  # III maj7
+  $roman = $mtr->parse('CMaj7');  # IIImaj7
   $roman = $mtr->parse('D7');     # IV7
   $roman = $mtr->parse('Em');     # v
 
